@@ -109,6 +109,21 @@ def test_slow(benchmark):
     assert 1 == 1
 '''
 
+FIXTURES_ALSO_SKIPPED_TEST = '''
+import pytest
+
+@pytest.fixture
+def dep():
+    print("""
+dep created""")
+
+def test_normal(dep):
+    pass
+
+def test_bench(benchmark):
+    benchmark.pedantic(lambda: None)
+'''
+
 GROUPING_TEST = '''
 import pytest
 
@@ -407,6 +422,16 @@ def test_only_override_skip(testdir):
     ])
 
 
+def test_fixtures_also_skipped(testdir):
+    test = testdir.makepyfile(FIXTURES_ALSO_SKIPPED_TEST)
+    result = testdir.runpytest_subprocess('--benchmark-only', '-s', test)
+    result.stdout.fnmatch_lines([
+        "*collected 2 items",
+        "*====== 1 passed, 1 skipped in * ======*",
+    ])
+    assert 'dep created' not in result.stdout.lines
+
+
 def test_conflict_between_only_and_disable(testdir):
     test = testdir.makepyfile(SIMPLE_TEST)
     result = testdir.runpytest_subprocess('--benchmark-only', '--benchmark-disable', test)
